
pybugsnag
=========


.. image:: https://badge.fury.io/py/pybugsnag.svg
   :target: https://badge.fury.io/py/pybugsnag
   :alt: PyPI version


.. image:: https://travis-ci.org/jpetrucciani/pybugsnag.svg?branch=master
   :target: https://travis-ci.org/jpetrucciani/pybugsnag
   :alt: Build Status


.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code style: black


A python wrapper for the Bugsnag Data Access API

COMING SOON!

Quick start
-----------

Installation
^^^^^^^^^^^^

.. code-block:: bash

   # install pybugsnag
   pip install pybugsnag

Basic Usage
^^^^^^^^^^^

.. code-block:: python

   import pybugsnag
